src/ztfy/utils/interfaces.py
branchZTK-1.1
changeset 174 380f23a1587e
parent 173 7164eb24f949
parent 172 cca95b4ff0c5
child 176 a7275e2a9252
--- a/src/ztfy/utils/interfaces.py	Mon Sep 24 08:49:04 2012 +0200
+++ b/src/ztfy/utils/interfaces.py	Mon Sep 24 08:54:09 2012 +0200
@@ -179,11 +179,11 @@
                             description=_("Realm name on ZEO server"),
                             required=False)
 
-    def getJSONSettings(self):
+    def getSettings(self):
         """Get ZEO connection setting as a JSON dict"""
 
-    def update(self, values):
-        """Update connection properties from given dict values"""
+    def update(self, settings):
+        """Update internal fields with given settings dict"""
 
     def getConnection(self, wait=False):
         """Open ZEO connection with given settings"""